##  Benefits
Some of the benefits of Collibra integration include:
  * Increased Data Transparency: Collibra integration offers clarity on where the data is mastered and how it flows within the IT landscape, helping stakeholders to identify data dependencies, optimize data flows, and ensure data integrity and security throughout its lifecycle.
  * Enhanced Data Accountability: The integration automates the mapping of data owners from Collibra to SAP LeanIX, ensuring clear ownership and improved accountability.
  * Expanded Data Accessibility: Enables you to leverage data across the enterprise while facilitating sound data governance practices.
